==> court-scraper-0.1.2.tar.gz: court-scraper-0.1.2/setup.py <==
#!/usr/bin/env python
"""
.. image:: https://img.shields.io/pypi/v/court-scraper.svg
        :target: https://pypi.python.org/pypi/court-scraper
        :alt: PyPI version badge

.. image:: https://img.shields.io/pypi/pyversions/court-scraper.svg
        :target: https://pypi.python.org/pypi/court-scraper
        :alt: Python versions badge

.. image:: https://github.com/biglocalnews/court-scraper/actions/workflows/tests.yaml/badge.svg?branch=master
        :target: https://github.com/biglocalnews/court-scraper/actions/workflows/tests.yaml
        :alt: GitHub Actions build status badge

.. image:: https://readthedocs.org/projects/court-scraper/badge/?version=latest
        :target: https://court-scraper.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://badges.gitter.im/court-scraper/general.svg
        :target: https://gitter.im/court-scraper/general?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge
        :alt: Gitter badge


Court Scraper
-------------

The `court-scraper` package provides a Python library and command-line
tool that help search for and download case information from local court system
websites in the United States. This library primarily focuses on supporting the ability
to scrape county-level court data by case number and date range.

* Documentation: http://court-scraper.readthedocs.io/en/latest/
* GitHub: https://github.com/biglocalnews/court-scraper
* PyPI: https://pypi.python.org/pypi/court-scraper
* Gitter: https://gitter.im/court-scraper/general
* Free and open source software: `Apache license`_

.. _Apache license: https://github.com/biglocalnews/court-scraper/blob/master/LICENSE

"""
from setuptools import find_packages, setup


def version_scheme(version):
    """
    Version scheme hack for setuptools_scm.
    Appears to be necessary to due to the bug documented here: https://github.com/pypa/setuptools_scm/issues/342
    If that issue is resolved, this method can be removed.
    """
    import time

    from setuptools_scm.version import guess_next_version

    if version.exact:
        return version.format_with("{tag}")
    else:
        _super_value = version.format_next_version(guess_next_version)
        now = int(time.time())
        return _super_value + str(now)


def local_version(version):
    """
    Local version scheme hack for setuptools_scm.
    Appears to be necessary to due to the bug documented here: https://github.com/pypa/setuptools_scm/issues/342
    If that issue is resolved, this method can be removed.
    """
    return ""


requirements = [
    "anticaptchaofficial",
    "bs4",
    "click",
    "click-option-group",
    "cssselect",
    "lxml",
    "my-fake-useragent",
    "pyyaml",
    "retrying",
    "selenium",
    "sqlalchemy",
    "typing-extensions",
]


test_requirements = ["flake8", "pytest", "pytest-vcr"]


setup(
    name="court-scraper",
    description="Command-line tool for scraping data from U.S. county courts",
    long_description=__doc__,
    long_description_content_type="text/x-rst",
    author="Serdar Tumgoren",
    author_email="zstumgoren@gmail.com",
    url="https://github.com/biglocalnews/court-scraper",
    packages=find_packages(),
    package_data={"court_scraper": ["data/*.csv"]},
    entry_points="""
        [console_scripts]
        court-scraper=court_scraper.cli:cli
    """,
    install_requires=requirements,
    license="ISC license",
    zip_safe=False,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: ISC License (ISCL)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    test_suite="tests",
    tests_require=test_requirements,
    project_urls={
        "Maintainer": "https://github.com/biglocalnews",
        "Source": "https://github.com/biglocalnews/court-scraper",
        "Tracker": "https://github.com/biglocalnews/court-scraper/issues",
    },
    setup_requires=["setuptools_scm"],
    use_scm_version={"version_scheme": version_scheme, "local_scheme": local_version},
)

==> court-scraper-0.1.3.tar.gz: court-scraper-0.1.3/setup.py <==
import os

from setuptools import find_packages, setup


def read(file_name):
    """Read the provided file."""
    this_dir = os.path.dirname(__file__)
    file_path = os.path.join(this_dir, file_name)
    with open(file_path) as f:
        return f.read()


def version_scheme(version):
    """
    Version scheme hack for setuptools_scm.
    Appears to be necessary to due to the bug documented here: https://github.com/pypa/setuptools_scm/issues/342
    If that issue is resolved, this method can be removed.
    """
    import time

    from setuptools_scm.version import guess_next_version

    if version.exact:
        return version.format_with("{tag}")
    else:
        _super_value = version.format_next_version(guess_next_version)
        now = int(time.time())
        return _super_value + str(now)


def local_version(version):
    """
    Local version scheme hack for setuptools_scm.
    Appears to be necessary to due to the bug documented here: https://github.com/pypa/setuptools_scm/issues/342
    If that issue is resolved, this method can be removed.
    """
    return ""


setup(
    name="court-scraper",
    description="Command-line tool for scraping data from U.S. county courts",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="Big Local News",
    author_email="biglocalnews@stanford.edu",
    url="https://github.com/biglocalnews/court-scraper",
    packages=find_packages(),
    package_data={"court_scraper": ["data/*.csv"]},
    entry_points="""
        [console_scripts]
        court-scraper=court_scraper.cli:cli
    """,
    install_requires=[
        "anticaptchaofficial",
        "bs4",
        "click",
        "click-option-group",
        "cssselect",
        "lxml",
        "my-fake-useragent",
        "pyyaml",
        "retrying",
        "selenium",
        "sqlalchemy",
        "typing-extensions",
    ],
    license="ISC license",
    zip_safe=False,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: ISC License (ISCL)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    test_suite="tests",
    tests_require=["flake8", "pytest", "pytest-vcr"],
    project_urls={
        "Maintainer": "https://github.com/biglocalnews",
        "Source": "https://github.com/biglocalnews/court-scraper",
        "Tracker": "https://github.com/biglocalnews/court-scraper/issues",
    },
    setup_requires=["setuptools_scm"],
    use_scm_version={"version_scheme": version_scheme, "local_scheme": local_version},
)
